
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_management_MBeanRegistrationException__
#define __javax_management_MBeanRegistrationException__

#pragma interface

#include <javax/management/MBeanException.h>
extern "Java"
{
  namespace javax
  {
    namespace management
    {
        class MBeanRegistrationException;
    }
  }
}

class javax::management::MBeanRegistrationException : public ::javax::management::MBeanException
{

public:
  MBeanRegistrationException(::java::lang::Exception *);
  MBeanRegistrationException(::java::lang::Exception *, ::java::lang::String *);
private:
  static const jlong serialVersionUID = 4482382455277067805LL;
public:
  static ::java::lang::Class class$;
};

#endif // __javax_management_MBeanRegistrationException__
